-- ============================================================
--   Nom de la base   :  MCD_HOTEL                             
--   Nom de SGBD      :  INFORMIX SQL 7.1                      
--   Date de cration :  16/01/2001  22:32   
--   Copyright        :  Frdric BROUARD                                       
-- ============================================================

-- ============================================================
--   Table : T_CHAMBRE                                         
-- ============================================================
create table T_CHAMBRE
(
    CHB_ID              INTEGER                not null,
    CHB_NUMERO          SMALLINT               not null,
    CHB_ETAGE           CHAR(3)                        ,
    CHB_BAIN            DEC(1)                 default 0 not null,
    CHB_DOUCHE          DEC(1)                 default 1 not null,
    CHB_WC              DEC(1)                 default 1 not null,
    CHB_COUCHAGE        SMALLINT               not null,
    CHB_POSTE_TEL       CHAR(3)                        ,
    primary key (CHB_ID) constraint PK_T_CHAMBRE
);

-- ============================================================
--   Table : T_TARIF                                           
-- ============================================================
create table T_TARIF
(
    TRF_DATE_DEBUT      DATE                   not null,
    TRF_TAUX_TAXES      NUMERIC                not null,
    TRF_PETIT_DEJEUNE   MONEY                  not null,
    primary key (TRF_DATE_DEBUT) constraint PK_T_TARIF
);

-- ============================================================
--   Table : T_PLANNING                                        
-- ============================================================
create table T_PLANNING
(
    PLN_JOUR            DATE                   not null,
    primary key (PLN_JOUR) constraint PK_T_PLANNING
);

-- ============================================================
--   Table : T_TITRE                                           
-- ============================================================
create table T_TITRE
(
    TIT_CODE            CHAR(8)                not null,
    TIT_LIBELLE         VARCHAR(32)            not null,
    primary key (TIT_CODE) constraint PK_T_TITRE
);

-- ============================================================
--   Table : T_TYPE                                            
-- ============================================================
create table T_TYPE
(
    TYP_CODE            CHAR(8)                not null,
    TYP_LIBELLE         VARCHAR(32)            not null,
    primary key (TYP_CODE) constraint PK_T_TYPE
);

-- ============================================================
--   Table : T_MODE_PAIEMENT                                   
-- ============================================================
create table T_MODE_PAIEMENT
(
    PMT_CODE            CHAR(8)                not null,
    PMT_LIBELLE         VARCHAR(64)            not null,
    primary key (PMT_CODE) constraint PK_T_MODE_PAIEMENT
);

-- ============================================================
--   Table : T_CLIENT                                          
-- ============================================================
create table T_CLIENT
(
    CLI_ID              INTEGER                not null,
    TIT_CODE            CHAR(8)                        ,
    CLI_NOM             CHAR(32)               not null,
    CLI_PRENOM          VARCHAR(25)                    ,
    CLI_ENSEIGNE        VARCHAR(100)                   ,
    primary key (CLI_ID) constraint PK_T_CLIENT
);

-- ============================================================
--   Table : T_FACTURE                                         
-- ============================================================
create table T_FACTURE
(
    FAC_ID              INTEGER                not null,
    CLI_ID              INTEGER                not null,
    PMT_CODE            CHAR(8)                        ,
    FAC_DATE            DATE                   not null,
    FAC_PMT_DATE        DATE                           ,
    primary key (FAC_ID) constraint PK_T_FACTURE
);

-- ============================================================
--   Table : T_ADRESSE                                         
-- ============================================================
create table T_ADRESSE
(
    ADR_ID              INTEGER                not null,
    CLI_ID              INTEGER                not null,
    ADR_LIGNE1          VARCHAR(32)            not null,
    ADR_LIGNE2          VARCHAR(32)                    ,
    ADR_LIGNE3          VARCHAR(32)                    ,
    ADR_LIGNE4          VARCHAR(32)                    ,
    ADR_CP              CHAR(5)                not null,
    ADR_VILLE           CHAR(32)               not null,
    primary key (ADR_ID) constraint PK_T_ADRESSE
);

-- ============================================================
--   Table : T_TELEPHONE                                       
-- ============================================================
create table T_TELEPHONE
(
    TEL_ID              INTEGER                not null,
    CLI_ID              INTEGER                not null,
    TYP_CODE            CHAR(8)                not null,
    TEL_NUMERO          CHAR(20)               not null,
    TEL_LOCALISATION    VARCHAR(64)                    ,
    primary key (TEL_ID) constraint PK_T_TELEPHONE
);

-- ============================================================
--   Table : T_EMAIL                                           
-- ============================================================
create table T_EMAIL
(
    EML_ID              INTEGER                not null,
    CLI_ID              INTEGER                not null,
    EML_ADRESSE         VARCHAR(100)           not null,
    EML_LOCALISATION    VARCHAR(64)                    ,
    primary key (EML_ID) constraint PK_T_EMAIL
);

-- ============================================================
--   Table : T_LIGNE_FACTURE                                   
-- ============================================================
create table T_LIGNE_FACTURE
(
    LIF_ID              INTEGER                not null,
    FAC_ID              INTEGER                not null,
    LIF_QTE             NUMERIC                not null,
    LIF_REMISE_POURCEN  NUMERIC                        ,
    LIF_REMISE_MONTANT  MONEY                          ,
    LIF_MONTANT         MONEY                  not null,
    LIF_TAUX_TVA        NUMERIC                not null,
    primary key (LIF_ID) constraint PK_T_LIGNE_FACTURE
);

-- ============================================================
--   Table : TJ_TRF_CHB                                        
-- ============================================================
create table TJ_TRF_CHB
(
    CHB_ID              INTEGER                not null,
    TRF_DATE_DEBUT      DATE                   not null,
    TRF_CHB_PRIX        MONEY                  not null,
    primary key (CHB_ID, TRF_DATE_DEBUT) constraint PK_TJ_TRF_CHB
);

-- ============================================================
--   Table : TJ_CHB_PLN_CLI                                    
-- ============================================================
create table TJ_CHB_PLN_CLI
(
    CHB_ID              INTEGER                not null,
    PLN_JOUR            DATE                   not null,
    CLI_ID              INTEGER                not null,
    CHB_PLN_CLI_NB_PER  SMALLINT               not null,
    CHB_PLN_CLI_RESERV  DEC(1)                 default 0 not null,
    CHB_PLN_CLI_OCCUPE  DEC(1)                 default 1 not null,
    primary key (CHB_ID, PLN_JOUR) constraint PK_TJ_CHB_PLN_CLI
);

alter table T_CLIENT
    add constraint (foreign key  (TIT_CODE)
       references T_TITRE (TIT_CODE) constraint FK_L_CLI_TIT_65);

alter table T_FACTURE
    add constraint (foreign key  (CLI_ID)
       references T_CLIENT (CLI_ID) constraint FK_L_FAC_CLI_70);

alter table T_FACTURE
    add constraint (foreign key  (PMT_CODE)
       references T_MODE_PAIEMENT (PMT_CODE) constraint FK_TJ_FAC_PM_72);

alter table T_ADRESSE
    add constraint (foreign key  (CLI_ID)
       references T_CLIENT (CLI_ID) constraint FK_L_ADR_CLI_66);

alter table T_TELEPHONE
    add constraint (foreign key  (CLI_ID)
       references T_CLIENT (CLI_ID) constraint FK_L_TEL_CLI_67);

alter table T_TELEPHONE
    add constraint (foreign key  (TYP_CODE)
       references T_TYPE (TYP_CODE) constraint FK_L_TEL_TYP_68);

alter table T_EMAIL
    add constraint (foreign key  (CLI_ID)
       references T_CLIENT (CLI_ID) constraint FK_L_EML_CLI_69);

alter table T_LIGNE_FACTURE
    add constraint (foreign key  (FAC_ID)
       references T_FACTURE (FAC_ID) constraint FK_L_LIF_FAC_71);

alter table TJ_TRF_CHB
    add constraint (foreign key  (CHB_ID)
       references T_CHAMBRE (CHB_ID) constraint FK_L_CHB_TRF_56);

alter table TJ_TRF_CHB
    add constraint (foreign key  (TRF_DATE_DEBUT)
       references T_TARIF (TRF_DATE_DEBUT) constraint FK_L_TRF_CHB_57);

alter table TJ_CHB_PLN_CLI
    add constraint (foreign key  (CHB_ID)
       references T_CHAMBRE (CHB_ID) constraint FK_L_CHB_PLN_62);

alter table TJ_CHB_PLN_CLI
    add constraint (foreign key  (PLN_JOUR)
       references T_PLANNING (PLN_JOUR) constraint FK_L_PLN_CHB_63);

alter table TJ_CHB_PLN_CLI
    add constraint (foreign key  (CLI_ID)
       references T_CLIENT (CLI_ID) constraint FK_L_CLI_CHB_64);

